![me](https://img.shields.io/pypi/v/pytectonic?style=flat-square)
![me](https://img.shields.io/github/license/gregyjames/tectonic?style=flat-square)
![me](https://img.shields.io/github/actions/workflow/status/gregyjames/tectonic/python-package.yml?style=flat-square)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/2f633f948ced4dc3bc795a89dfa58774)](https://www.codacy.com/gh/gregyjames/Tectonic/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=gregyjames/Tectonic&amp;utm_campaign=Badge_Grade)

# Tectonic
A python library for real estate modeling and evaluation

## Helpers
1. NOI
2. cap_rate
3. price_to_rent_ratio
4. cash_on_return
5. GRM

## Valuation Models
1. discounted_NOI
2. band_of_investing
3. price_per_squarefoot

## Payments
1. Mortgage